if [ -z "$DQ2_LOCATION" ]; then
  echo "Missing environment variable DQ2_LOCATION!"
  exit 1
fi

WEBSITE=http://atlas.web.cern.ch/Atlas/GROUPS/DATABASE/project/ddm/releases

  if [ ! -f "$DQ2_LOCATION/conf/site_conf.py" ]; then
    echo "Missing file $DQ2_LOCATION/conf/site_conf.py"
    echo "Will try to download file from DQ2 web page"
    wget -q "${WEBSITE}/sites/`hostname -f`/site_conf.py" -O "$DQ2_LOCATION/conf/site_conf.py"
    if [ "$?" != "0" ]; then
      echo "Site configuration file not found!"
      rm -f $DQ2_LOCATION/conf/site_conf.py
      exit 1
    else
      echo "site_conf.py found on DQ2 web page"
    fi
  fi

  # DQ2 db username/pwd
  DQ2_DB_USERNAME=dq2user
  DQ2_DB_PWD=dqpwd


  # LCG VO-box proxy renewal host certificate
  ln -f -s /opt/vobox/atlas/renewal-proxy.pem $DQ2_LOCATION/certs/dq2.cert
  ln -f -s /opt/vobox/atlas/renewal-proxy.pem $DQ2_LOCATION/certs/dq2.key

  # Generate claims config files
  cat > $DQ2_LOCATION/conf/claims_server_conf.py << EOF
# Claims MySQL DB settings
claims_db = 'claims'
claims_host = '`hostname`'
claims_user = '$DQ2_DB_USERNAME'
claims_passwd = '$DQ2_DB_PWD'
EOF
  cat > $DQ2_LOCATION/conf/claims_client_conf.py << EOF
secure_claims_server = {
    'hostname' : '`hostname`',
    'port' : 8443
    }
insecure_claims_server = {
    'hostname' : '`hostname`',
    'port' : 8000
    }
EOF

  # create local databases
  cd $DQ2_LOCATION
  wget -q ${WEBSITE}/scripts/post_install_mysqlserver.sh
  sh post_install_mysqlserver.sh $DQ2_DB_USERNAME $DQ2_DB_PWD
  rm post_install_mysqlserver.sh

  cd $DQ2_LOCATION
  ./mysql.sh start

  # let it start
  sleep 2
  source setup.sh
  python common/setup_local_cats.py
  ./mysql.sh stop

  # create cron job
  cat > $DQ2_LOCATION/services.cron << EOF
DQ2_LOCATION=$DQ2_LOCATION
*/5 * * * * cd $DQ2_LOCATION; source setup.sh; ./mysql.sh start; httpd/bin/apachectl -k start
0 0 * * * /usr/sbin/logrotate -s \$DQ2_LOCATION/log/log.status \$DQ2_LOCATION/log/log.conf
EOF

  # set up log files
  cat > $DQ2_LOCATION/log/log.conf <<EOF
compress
  
       $DQ2_LOCATION/log/DDMSubscriptions.log {
           rotate 20
           daily
       }
EOF

  echo "Done."


